@@ -75,6 +75,8 @@ from types import GeneratorType, ModuleType
 from collections import deque
 from binascii import a2b_hex, b2a_hex
 
+VERSION = '0.02'
+
 PYTHON3 = sys.version_info >= (3, 0)
 if PYTHON3:
     import pickle
@@ -1452,7 +1454,7 @@ def server_main(args=None):
         args = sys.argv[1:]
 
     key = ''
-    options = OptionParser()
+    options = OptionParser(description="Runs the EasyCluster service and generates keyfiles", version=VERSION)
     add_key_options(options)
     options.add_option('-S', '--serve', metavar='FILE', action='store_true', help='Run the server on the specified port')
     options.add_option('-g', '--generate', metavar='FILE', help='Generate random HMAC key and '
